@@ -24,7 +24,7 @@
 #include "svnqt/revision.h"
 
 class RevisionButtonImpl: public RevisionButton {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
