@@ -62,7 +62,7 @@ namespace TDEIO {
 */
 class SvnActions : public TQObject,public SimpleLogCb
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     enum ThreadType {
