@@ -19,7 +19,7 @@
  ***************************************************************************/
 #include "svnlogdlgimp.h"
 #include "tdesvnsettings.h"
-#include "log_entry.hpp"
+#include "log_entry.h"
 #include "sub2qt.h"
 #include "svnactions.h"
 #include "revisionbuttonimpl.h"
