@@ -90,7 +90,7 @@ namespace svn
             const DiffOptions&diffoptions,
             bool ignore_mimetypes,
             bool include_merged_revisions
-                        ) throw (ClientException)
+                        )
   {
     Pool pool;
     svn_error_t *error;
