@@ -32,9 +32,9 @@
 #endif
 
 // svncpp
-#include "svnqt/client_impl.hpp"
+#include "svnqt/client_impl.h"
 #include "svn_opt.h"
-#include "svnqt/svnqt_defines.hpp"
+#include "svnqt/svnqt_defines.h"
 
 #include <tqmap.h>
 #include <tqstringlist.h>
