@@ -697,7 +697,7 @@ void tdeio_svnProtocol::commit(const KURL::List&url)
         kdWarning()<<msg<<endl;
         return;
     }
-    if (replyType!=TQSTRINGLIST_OBJECT_NAME_STRING) {
+    if (replyType!="TQStringList") {
         msg = "Wrong reply type";
         kdWarning()<<msg<<endl;
         return;
